@@ -12,10 +12,11 @@ from collections import namedtuple
 from io import StringIO
 
 from humanfriendly import format_size
+from argparse_addons import IntegerRangeType
 
 
 __author__ = 'Erik Moqvist'
-__version__ = '17.3.0'
+__version__ = '17.4.0'
 
 
 DEFAULT_WORD_SIZE_BITS = 8
@@ -1798,34 +1799,6 @@ def _do_fill(args):
             fout.write(data)
 
 
-class IntegerRangeType:
-
-    def __init__(self, minimum, maximum):
-        self.minimum = minimum
-        self.maximum = maximum
-
-    def __call__(self, string):
-        value = int(string, 0)
-
-        if self.minimum is not None and self.maximum is not None:
-            if not self.minimum <= value <= self.maximum:
-                raise argparse.ArgumentTypeError(
-                    f'{string} is not in the range {self.minimum}..{self.maximum}')
-        elif self.minimum is not None:
-            if value < self.minimum:
-                raise argparse.ArgumentTypeError(
-                    f'{string} is not {self.minimum} or higher')
-        elif self.maximum is not None:
-            if value > self.maximum:
-                raise argparse.ArgumentTypeError(
-                    f'{string} is not {self.maximum} or lower')
-
-        return value
-
-    def __repr__(self):
-        return 'integer'
-
-
 def _main():
     parser = argparse.ArgumentParser(
         description='Various binary file format utilities.')
